man > GIT-SYMBOLIC-REF(1)

⚡ TLDR: GIT-SYMBOLIC-REF (tldr-pages)

Read, change, or delete files that store references.

  • Store a reference by a name
    git symbolic-ref refs/{{name}} {{ref}}
  • Store a reference by name, including a message with a reason for the update
    git symbolic-ref -m "{{message}}" refs/{{name}} refs/heads/{{branch_name}}
  • Read a reference by name
    git symbolic-ref refs/{{name}}
  • Delete a reference by name
    git symbolic-ref {{-d|--delete}} refs/{{name}}
  • For scripting, hide errors with `--quiet` and use `--short` to simplify ("refs/heads/X" prints as "X")
    git symbolic-ref {{-q|--quiet}} --short refs/{{name}}
GIT-SYMBOLIC-REF(1)                          Git Manual                          GIT-SYMBOLIC-REF(1)

NAME
       git-symbolic-ref - Read, modify and delete symbolic refs

SYNOPSIS
       git symbolic-ref [-m <reason>] <name> <ref>
       git symbolic-ref [-q] [--short] [--no-recurse] <name>
       git symbolic-ref --delete [-q] <name>


DESCRIPTION
       Given one argument, reads which branch head the given symbolic ref refers to and outputs its
       path, relative to the .git/ directory. Typically you would give HEAD as the <name> argument
       to see which branch your working tree is on.

       Given two arguments, creates or updates a symbolic ref <name> to point at the given branch
       <ref>.

       Given --delete and an additional argument, deletes the given symbolic ref.

       A symbolic ref is a regular file that stores a string that begins with ref: refs/. For
       example, your .git/HEAD is a regular file whose content is ref: refs/heads/master.

OPTIONS
       -d, --delete
           Delete the symbolic ref <name>.

       -q, --quiet
           Do not issue an error message if the <name> is not a symbolic ref but a detached HEAD;
           instead exit with non-zero status silently.

       --short
           When showing the value of <name> as a symbolic ref, try to shorten the value, e.g. from
           refs/heads/master to master.

       --recurse, --no-recurse
           When showing the value of <name> as a symbolic ref, if <name> refers to another symbolic
           ref, follow such a chain of symbolic refs until the result no longer points at a symbolic
           ref (--recurse, which is the default).  --no-recurse stops after dereferencing only a
           single level of symbolic ref.

       -m
           Update the reflog for <name> with <reason>. This is valid only when creating or updating
           a symbolic ref.

NOTES
       In the past, .git/HEAD was a symbolic link pointing at refs/heads/master. When we wanted to
       switch to another branch, we did ln -sf refs/heads/newbranch .git/HEAD, and when we wanted to
       find out which branch we are on, we did readlink .git/HEAD. But symbolic links are not
       entirely portable, so they are now deprecated and symbolic refs (as described above) are used
       by default.

       git symbolic-ref will exit with status 0 if the contents of the symbolic ref were printed
       correctly, with status 1 if the requested name is not a symbolic ref, or 128 if another error
       occurs.

GIT
       Part of the git(1) suite

Git 2.43.0                                   07/02/2025                          GIT-SYMBOLIC-REF(1)

Generated by phpman v4.11.2-59-gf06411a · Markdown · JSON Author: Che Dong Under GNU General Public License
2026-10-15 19:57 @2600:1f28:365:80b0:fe6c:4ae8:e422:8cd7
CrawledBy CCBot/2.0 (https://commoncrawl.org/faq/)
Valid XHTML 1.0 Transitional!Valid CSS!